@@ -25,13 +25,20 @@ Magma lists are lists of files which can be downloaded via magnet links.
 
 They are written in yaml format to be easily readable as well as flexible and powerful. 
 
+
+This script parses the basic features of MAGMAv0.4, which is being specified at the moment. 
+It doesn't parse the current MAGMAv0.2 files!
+
+Use it only, if you want to take a peek at what the updated specification will bring. 
+
+
 It depends on U{pyyaml <http://pyyaml.org/>}. 
 
 An example magma file is I{example-0.4.magma}. 
 
 This API documentation is avaible from U{http://gnuticles.gnufu.net/pymagma/}, and the code is avaible from a U{Mercurial repository <http://freehg.org/u/ArneBab/magma/>}. 
 
-The module can also be found in the U{Python Package Index (PyPI) <http://pypi.python.org/pypi/magma/>}
+The module can also be found in the U{Python Package Index (PyPI) <http://pypi.python.org/pypi/magma/>}. 
 
 Usage of this module
 ====================
@@ -42,8 +49,8 @@ from magma import Magma
 
 or 
 
-    >>> magma = Magma(input_files=["input_file.txt", "input_file2.txt"])
-    
+    >>> magma = Magma(input_files=["input_file.txt", "input_file2.txt"])    
+
 
 API / usage
 ===========
@@ -106,13 +113,25 @@ Output all magnet links inside the magma list.
     
 """
 
+#### Background ####
+
+__author__ = 'Arne Babenhauserheide <arne_bab ät web punkt de>'
+__copyright__ = 'Copyright (C) 2007 Arne Babenhauserheide'
+__date__ = '2008-05-09'
+__licence__ = 'GPL-2 or later'
+__program__ = 'Manage magma lists'
+__version__ = '0.2'
+__depends__ = 'hashlib, base64, pyyaml'
+
+#### Background ####
+
 from magma_list import Magma
 
 #### Self-Test ####
 
 def _test():
     """Do all doctests"""
-    # Get the testmod function from the doctest module
+    # Get the testmod function from the doctest module. 
     from doctest import testmod
     # And call it. 
     testmod()
