@@ -57,6 +57,7 @@ class Magma(object):
             - Passing the data of files along with magma metadata to create the list. 
             - Passing the indizes of files to automatically slice the list. maybe even with the syntax sliced_magma = magma[a:b]
             - Readout metadata from files, for example using the taglib or such. 
+            - If a dir gets passed, add all files within that dir. Alsa a parameter to ask, if it should be done rekursively. 
         
         """
         #: All data inside the Magma list
@@ -70,6 +71,8 @@ class Magma(object):
         # If we get single files, we create the magma file from the files. 
         elif input_files is not None: 
             self.data = self.create_magma_from_files(file_paths=input_files)
+        else: 
+            raise Exception("No input specified. You need to pass one of data=DATA, magma_file=PATH or input_files=[PATH1, PATH2, ...]")
             
         # If we get a creator name, also add that. 
         if creator is not None: 
@@ -179,7 +182,7 @@ class MagmaFile(object):
         """A file inside the magma list"""
         #: All data of the file
         self.data = data
-        #: The name of teh file, so we can easily print it. 
+        #: The name of the file, so we can easily print it. 
         self.name = self.data["name"]
         #: The sha1 hash of the file. 
         self.sha1_hash = self.data["hash"]["sha1"]
